@@ -131,7 +131,7 @@ class Line(Graph):
 
         y_pos = compute_scale(
             self._box.ymin, self._box.ymax, self.logarithmic, self.order_min
-        ) if not self.y_labels else map(float, self.y_labels)
+        ) if not self.y_labels else list(map(float, self.y_labels))
 
         self._y_labels = list(zip(map(self._format, y_pos), y_pos))
 
